| Title: | Data from Bayesian Population Analysis using Winbugs |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Joe Thorley [aut, cre] (ORCID: <https://orcid.org/0000-0002-7683-4592>) |
| Maintainer: | Joe Thorley <[email protected]> |
| License: | file LICENSE |
| Version: | 0.0.0.9001 |
| Built: | 2026-06-05 19:50:19 UTC |
| Source: | https://github.com/poissonconsulting/bauw |
The cerambycid "blue bug" beetle (Rosalia alpina) replicated woodpile counts from the hills around Movelier in the Swiss Jura mountains by Michaeal Schaub in 2009 from Kery & Schaub (2011 p.427-428).
bluebugbluebug
A data frame with 27 rows and 21 columns
The variables are as follows:
site the site (woodpile).
siteno the site number (w.
forest_edge a indicator variable for whether or not the site
was on the edge of the forest.
det1, det2, ..., det6 the larval count by visit.
date1, date2, ..., date6 the date by visit.
h1, h2, ..., h6 the hours in the afternoon by visit.
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The six-spot burnet moth (Zygaena filipendulae) replicate counts from the Swiss butterfly monitoring program from Kery & Schaub (2011 p.445-446).
burnetburnet
A data frame with 665 rows and 4 columns
The variables are as follows:
site the site.
day the day ("season").
count1 the first count.
count2 the second count.
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The silver-washed fritillary (Argynnis paphia) butterfly duplicate site counts from Kery & Schaub (2011 p.396).
fritillaryfritillary
A data frame with 665 rows and 4 columns
The variables are as follows:
site the site surveyed.
day the day of the survey.
count1 the first count.
count2 the second count.
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The house martin (Delichon urbica) population annual counts from Magden (a small village in Northern Switzerland) collected by Reto Freuler from 1990 to 2009.
hmhm
A data frame with 20 rows and 2 columns
The variables are as follows:
hm the count (integer).
year the year (integer).
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The female Leisler's bats (Nyctalus leisleri) capture-recapture data collected by Wigbert Schorcht and colleagues in Thuringia (Germany) from 1989 to 2008 from Kery & Schaub (2011 p.231).
leislerileisleri
A data frame with 181 rows and 19 columns
The variables are as follows:
V1, V2, ..., V19 an indicator variable specify whether or not the
individual was 0 = undetected or 1 = detected.
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The showy lady's slipper (Cypripedium reginae) capture-recapture data collected by Kathy Gregg in Big Draft (West Virginia) from 1989 to 1999 from Kery & Schaub (2011 p.166).
orchidsorchids
A data frame with 250 rows and 11 columns
The variables are as follows:
V1, V2, ..., V11 the state of the individual plant by year
where 0 = undetected, 1 = vegetative and 2 = flowering.
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The long-eared owl (Asio otus) territory replicate detections from the 2009 breeding season by Simon Birrer from Kery & Schaub (2011 p.454).
owlsowls
A data frame with 40 rows and 11 columns
The variables are as follows:
territory the territory.
obs1, obs2, ..., obs5 the count by visit.
date1, date2, ..., date5 the day of the year by visit.
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The bird point count data from the Czech republic for point count number 610 in 2004-2005.
p610p610
A data frame with 146 rows and 9 columns
The variables are as follows:
species the species (factor with 146 levels).
point the point count number (integer with one value 610).
bm body mass (grams)
specnr the species number (integer with 146 values).
count1, count2, ..., count5 the number of individuals counted by occasion (1-5).
Kery & Schaub (2011 p.157) courtesy of Jiri Reif
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The peregrine falcon (Falco peregrinus) population breeding in the French Jura from 1964 to 2003.
peregrineperegrine
A data frame with 40 rows and 4 columns
The variables are as follows:
Year the year (integer).
Pairs the number of adult pairs (integer).
R.pairs the number of reproductive pairs (integer).
Eyasses the number of fledged young (integer).
Kery & Schaub (2011 p.64-65) courtesy of R.-J. Monneret
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The pen shell (Pinna nobilis) detection data from the Balearic Islands in 2010.
pinnapinna
A data frame with 143 rows and 3 columns
The variables are as follows:
d1 indicator for shell detected by first team.
d2 indicator for shell detected by second team.
width shell width (cm).
Kery & Schaub (2011 p.166) courtesy of Iris Hendriks and colleagues
Kery M & Schaub M (2011) Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)
The Swiss coal tit (Parus ater) annual territory counts from the Swiss breeding bird survey MHB from 1999 to 2007.
titstits
A data frame with 235 rows and 31 columns
The variables are as follows:
site the site code (factor with 235 levels).
spec the species (factor with one level = "Coaltit").
elevation the elevation im masl (integer).
forest the percent forest cover (integer).
y1999, y2000, ..., y2007 the site count by year (integer).
obs1999, obs2000, ..., obs2007 the observer code by year (integer).
first1999, first2000, ..., first2007 the first-time observer indicator by year (integer with two values 0 or 1).
Kery M & Schaub M Bayesian Population Analysis using WinBUGS. Academic Press. (https://www.vogelwarte.ch/en/research/population-biology/book-bpa/)